function [] = runAdjacentMinors_serial(n)
% run adjacent minors system 

% verify n >= 3
if n < 3
  disp(['ERROR: n must be at least 3!']);
end;

% setup A
syms a1_1;
A = zeros(3,n)*a1_1;
for j = 1:3
  for k = 1:n
    eval(['syms a',num2str(j),'_',num2str(k)]);
    A(j,k) = eval(['a',num2str(j),'_',num2str(k)]); 
  end;
end;

% setup f
f = zeros(n-2,1)*a1_1;
for j = 1:n-2
  f(j) = det(A(:,j:j+2));
end;

% create Bertini input files
X = zeros(n-2,1)*a1_1;
for j = 1:n-2
  eval(['syms x',num2str(j)]);
  X(j) = eval(['x',num2str(j)]);
end;
V = [reshape(A,[3*n 1]);1];
R = (rand(n-1,3*n)*2-1) + 1i*(rand(n-1,3*n)*2-1);

% create temporary file containing the system
F = fopen('input_system','w');
cX = 'variable_group '; cF = 'function '; cR = 'constant ';
for j = 1:n-2
  cX = [cX,'x',num2str(j)];
  cF = [cF,'f',num2str(j)];
  for k = 1:3*n
    cR = [cR,'r',num2str(j),'_',num2str(k),','];
  end;
  if j < n-2
    cX = [cX,','];
    cF = [cF,','];
  else
    cX = [cX,';'];
    cF = [cF,';'];
  end;
end;
for k = 1:3*n
  cR = [cR,'r',num2str(n-1),'_',num2str(k)];
  if k < 3*n
    cR = [cR,','];
  else
    cR = [cR,';'];
  end;
end;

fprintf(F,'INPUT\n%s\n%s\n%s\n',cX,cF,cR);
for j = 1:n-1
  for k = 1:3*n
    fprintf(F,'r%d_%d = %s + I*%s;\n',j,k,num2str(real(R(j,k)),15),num2str(imag(R(j,k)),15));
  end;
end;
C = 1;
for j = 1:3
  for k = 1:n
    c = ['a',num2str(j),'_',num2str(k),' = '];
    for l = 1:n-2
      c = [c,'r',num2str(l),'_',num2str(C),'*x',num2str(l),' + '];
    end;
    c = [c,'r',num2str(n-1),'_',num2str(C),';'];
    C = C+1;
    fprintf(F,'%s\n',c);
  end;
end;
for j = 1:n-2
  fprintf(F,'f%d = %s;\n',j,char(f(j)));
end;
fprintf(F,'END;\n');
fclose(F);

% dim-by-dim
F = fopen('input_dim','w');
fprintf(F,'CONFIG\nTrackType: 1;\nWitnessGenType: 1;\nWitnessSupersetOnly: 1;\nOutputLevel: -1;\nODEPredictor: 2;\nTrackTolBeforeEG: 1e-6;\nTrackTolDuringEG: 1e-6;\nFinalTol: 1e-10;\nEND;\n');
fclose(F);
eval(['!rm -rf input_dim_',num2str(n),'; cat input_dim input_system > input_dim_',num2str(n),'; rm -rf input_dim']);
eval(['!/usr/bin/time -o Dim mpirun -np 64 bertini input_dim_',num2str(n),' > /dev/null']);

F = fopen('Dim','r');
T = fscanf(F,'%euser %esystem %e:%e');
Dim = T(3)*60 + T(4);
disp(['Dim-by-dim: ',num2str(Dim),' sec']);

% regen cascade
F = fopen('input_rc','w');
fprintf(F,'CONFIG\nTrackType: 1;\nWitnessGenType: 2;\nWitnessSupersetOnly: 1;\nOutputLevel: -1;\nODEPredictor: 2;\nTrackTolBeforeEG: 1e-6;\nTrackTolDuringEG: 1e-6;\nFinalTol: 1e-10;\nEND;\n');
fclose(F);
eval(['!rm -rf input_rc_',num2str(n),'; cat input_rc input_system > input_rc_',num2str(n),'; rm -rf input_rc']);
eval(['!/usr/bin/time -o RC mpirun -np 64 bertini input_rc_',num2str(n),' > /dev/null']);

F = fopen('RC','r');
T = fscanf(F,'%euser %esystem %e:%e');
RC = T(3)*60 + T(4);
disp(['Regen cascade: ',num2str(RC),' sec']);

% cascade
F = fopen('input_c','w');
fprintf(F,'CONFIG\nTrackType: 1;\nWitnessGenType: 0;\nWitnessSupersetOnly: 1;\nOutputLevel: -1;\nODEPredictor: 2;\nTrackTolBeforeEG: 1e-6;\nTrackTolDuringEG: 1e-6;\nFinalTol: 1e-10;\nEND;\n');
fclose(F);
eval(['!rm -rf input_c_',num2str(n),'; cat input_c input_system > input_c_',num2str(n),'; rm -rf input_c']);
eval(['!/usr/bin/time -o C mpirun -np 64 bertini input_c_',num2str(n),' > /dev/null']);

F = fopen('C','r');
T = fscanf(F,'%euser %esystem %e:%e');
C = T(3)*60 + T(4);
disp(['Cascade: ',num2str(C),' sec']);

% first order general
X3 = veroneseDeg([transpose(X) 1],3);
F = fopen(['input_fog_',num2str(n)],'w');
fprintf(F,'CONFIG\nTrackType: 0;\nUserHomotopy: 2;\nOutputLevel: -1;\nODEPredictor: 2;\nTrackTolBeforeEG: 1e-6;\nTrackTolDuringEG: 1e-6;\nFinalTol: 1e-10;\nEND;\n');

S = (rand(n-2,length(X3))*2-1) + 1i*(rand(n-2,length(X3))*2-1);
cG = 'constant ';
for j = 1:n-2
  for k = 1:length(X3)
    cG = [cG,'s',num2str(j),'_',num2str(k)];
    if j < n-2 || k < length(X3)
      cG = [cG,','];
    else
      cG = [cG,';'];
    end;
  end;
end;

fprintf(F,'INPUT\n%s\n%s\n%s\n%s\npathvariable s;\nparameter t;\nt = s;\n',cX,cF,cR,cG);
for j = 1:n-1
  for k = 1:3*n
    fprintf(F,'r%d_%d = %s + I*%s;\n',j,k,num2str(real(R(j,k)),15),num2str(imag(R(j,k)),15));
  end;
end;
for j = 1:n-2
  for k = 1:length(X3)
    fprintf(F,'s%d_%d = %s + I*%s;\n',j,k,num2str(real(S(j,k)),15),num2str(imag(S(j,k)),15));
  end;
end;
C = 1;
for j = 1:3
  for k = 1:n
    c = ['a',num2str(j),'_',num2str(k),' = '];
    for l = 1:n-2
      c = [c,'r',num2str(l),'_',num2str(C),'*x',num2str(l),' + '];
    end;
    c = [c,'r',num2str(n-1),'_',num2str(C),';'];
    C = C+1;
    fprintf(F,'%s\n',c);
  end;
end;
for j = 1:n-2
  c = ['g',num2str(j),' = '];
  for k = 1:length(X3)
    c = [c,'s',num2str(j),'_',num2str(k),'*',char(X3(k))];
    if k < length(X3)
      c = [c,' + '];
    else
      c = [c,';'];
    end;
  end;
  fprintf(F,'%s\n',c);
end;
for j = 1:n-2
  fprintf(F,'f%d = (1-t)*(%s) + t*(1-t)*g%d + t*(x%d^3 - 1);\n',j,char(f(j)),j,j);
end;
fprintf(F,'END;\n');
fclose(F);

p = exp(2*pi*1i*(0:2)/3);
c = '['; 
C = 'Start = [';
for j = 1:n-2
  c = [c,'p',num2str(j)];
  C = [C,'p',num2str(j),'(:)'];
  if j < n-2
    c = [c,','];
    C = [C,','];
  else
    c = [c,'] = ndgrid(p);'];
    C = [C,'];'];
  end;
end;
eval(c);
eval(C);
CreateStart(Start,size(Start,1),size(Start,2),['start_fog_',num2str(n)]);

eval(['!/usr/bin/time -o FOG mpirun -np 64 bertini input_fog_',num2str(n),' start_fog_',num2str(n),' > /dev/null']);

F = fopen('FOG','r');
T = fscanf(F,'%euser %esystem %e:%e');
FOG = T(3)*60 + T(4);
disp(['First order gen: ',num2str(FOG),' sec']);

% first order general g = 0
F = fopen(['input_fo_',num2str(n)],'w');
fprintf(F,'CONFIG\nTrackType: 0;\nUserHomotopy: 2;\nOutputLevel: -1;\nODEPredictor: 2;\nTrackTolBeforeEG: 1e-6;\nTrackTolDuringEG: 1e-6;\nFinalTol: 1e-10;\nEND;\n');

fprintf(F,'INPUT\n%s\n%s\n%s\npathvariable s;\nparameter t;\nt = s;\n',cX,cF,cR);
for j = 1:n-1
  for k = 1:3*n
    fprintf(F,'r%d_%d = %s + I*%s;\n',j,k,num2str(real(R(j,k)),15),num2str(imag(R(j,k)),15));
  end;
end;
C = 1;
for j = 1:3
  for k = 1:n
    c = ['a',num2str(j),'_',num2str(k),' = '];
    for l = 1:n-2
      c = [c,'r',num2str(l),'_',num2str(C),'*x',num2str(l),' + '];
    end;
    c = [c,'r',num2str(n-1),'_',num2str(C),';'];
    C = C+1;
    fprintf(F,'%s\n',c);
  end;
end;
fprintf(F,'constant gamma;\ngamma = %s + I*%s;\n',num2str(rand()*2-1,15),num2str(rand()*2-1,15));
for j = 1:n-2
  fprintf(F,'f%d = (1-t)*(%s) + t*gamma*(x%d^3 - 1);\n',j,char(f(j)),j);
end;
fprintf(F,'END;\n');
fclose(F);

eval(['!/usr/bin/time -o FO mpirun -np 64 bertini input_fo_',num2str(n),' start_fog_',num2str(n),' > /dev/null']);

F = fopen('FO','r');
T = fscanf(F,'%euser %esystem %e:%e');
FO = T(3)*60 + T(4);
disp(['First order zero: ',num2str(FO),' sec']);

return;


