function [VM] = veroneseDeg(Pts, deg)
    % compute the Veronese embedding of 'Pts' in degree 'deg'

    numVars = length(Pts); % number of variables
    A = setupDegree(deg, numVars);

    % setup VM
    VM = veronese(Pts,A);
return;

function [M] = veronese(X, A)
    % compute the Veronese embedding based on A

    N = size(A,1);
    for j = N:-1:1
        M(1,j) = prod(X.^A(j,:));
    end;
return;

function [A] = setupDegree(deg, n)
    % setup degrees for Veronese embedding

    numRows = nchoosek(n+deg-1,deg);
    A = zeros(numRows,n);
    A(1,1) = deg;

    for j = 1:numRows-1
        % copy
        A(j+1,:) = A(j,:);
        % find target entry
        target = -1;
        for k = n-1:-1:1
            if A(j+1,k) ~= 0
                target = k;
                break;
            end;
        end;
        % move entry
        A(j+1,target) = A(j+1,target) - 1;
        A(j+1,target+1) = A(j+1,target+1) + 1;
        % move all of final entry to target+1 if not the same!
        if target ~= n-1
            A(j+1,target+1) = A(j+1,target+1) + A(j+1,n);
            A(j+1,n) = 0;
        end;
    end;
return;


